@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: IunoSettings.py 11300 2018-12-06 09:49:45Z Kevin $
+# $Id: IunoSettings.py 11430 2019-04-10 05:13:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $ (last)
-# $Date: 2018-12-06 18:49:45 +0900 (週四, 06 十二月 2018) $
-# $Revision: 11300 $
+# $Author: Lavender $ (last)
+# $Date: 2019-04-10 14:13:37 +0900 (週三, 10 四月 2019) $
+# $Revision: 11430 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -54,11 +54,11 @@ DATABASES = {
 }
 
 TIME_ZONE = 'Asia/Taipei' #'America/Chicago'
-LANGUAGE_CODE = 'zh-Hant' #'en-us'
+LANGUAGE_CODE = 'zh-hant' #'en-us'
 USE_I18N = True
 LANGUAGES = (
-  ('zh-tw', 'Traditional Chinese'),
-  ('zh-cn', 'Simplified Chinese'),
+  ('zh-hant', 'Traditional Chinese'),
+  ('zh-hans', 'Simplified Chinese'),
   ('en', 'English'),
 )
 
@@ -85,6 +85,23 @@ INSTALLED_APPS = (
     'Iuno.cloud.storage',
 )
 
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': [],
+        'APP_DIRS': True,
+        'OPTIONS': {
+            'context_processors': [
+                'django.template.context_processors.debug',
+                'django.template.context_processors.request',
+                'django.contrib.auth.context_processors.auth',
+                'django.contrib.messages.context_processors.messages',
+            ],
+        },
+    },
+]
+
 from Iuno.cloud.storage import DEFAULTS
 IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL = DEFAULTS[
     'IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL']
+
