@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11367 2019-02-19 12:09:40Z Lavender $
+# $Id: Patch.py 11432 2019-04-10 06:04:43Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-02-19 21:09:40 +0900 (週二, 19 二月 2019) $
-# $Revision: 11367 $
+# $Date: 2019-04-10 15:04:43 +0900 (週三, 10 四月 2019) $
+# $Revision: 11432 $
 #
 # Contributors:
 #  Bear
@@ -23,6 +23,22 @@ from Iuppiter.DjangoUtil import extendInstalledApps, extendMiddlewareClasses
 
 from .Util import update, populateEnvToSettings
 
+try:
+    import django
+
+    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
+                      django.VERSION[2])
+except ImportError:
+    warnings.warn("Unable to import django, many Iuno packages require it.")
+ 
+def patterns(prefix, *args): 
+    if DJANGO_VERSION >= 210: # django >= 1.11
+        return args
+    else:
+        from django.conf.urls import patterns as _patterns
+        
+        return _patterns(prefix, *args)
+
 def attachDebugSettings(settingsDict):
     """
     Attach debug related settings to settings.py.
@@ -188,7 +204,7 @@ def attachDebugURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
-    from django.conf.urls import url, include, patterns
+    from django.conf.urls import url, include
 
     try:
         import debug_toolbar
@@ -208,7 +224,7 @@ def attachURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
-    from django.conf.urls import url, include, patterns
+    from django.conf.urls import url, include
     from des import urls as des_urls
 
     urlpatterns += patterns('',
