@@ -11,9 +11,11 @@ sed -i -e "s#\$PWD#$PWD#g" cron/{{ jobName }}
 chmod +x cron/{{ jobName }}
 
 if (( $(crontab -l | grep -c "cron_{{ jobName }}" ) == 0 )) ; then
-    crontab -l > _cron  
-    env >> _cron  
+    crontab -l > _cron
+    if (( $(crontab -l | grep -c "APP_NAME=" ) == 0 )) ; then
+        env >> _cron
+    fi
     echo "{{ time }} $PWD/cron/{{ jobName }} >> $HOME/app/log/cron_{{ jobName }}.log" >> _cron
-fi
-crontab _cron
-rm -f _cron
\ No newline at end of file
+    crontab _cron
+    rm -f _cron
+fi
\ No newline at end of file
