@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 11244 2018-10-10 15:19:58Z Lavender $
+# $Id: start_project.py 11432 2019-04-10 06:04:43Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-10-11 00:19:58 +0900 (週四, 11 十月 2018) $
-# $Revision: 11244 $
+# $Date: 2019-04-10 15:04:43 +0900 (週三, 10 四月 2019) $
+# $Revision: 11432 $
 
 import os
 import sys
@@ -59,46 +59,80 @@ class Command(BaseCommand):
 
         import django
 
-        if not (django.VERSION[0] == 1 and django.VERSION[1] == 8):
-            raise CommandError("Only support django 1.8.x")
+        if not (
+            django.VERSION[0] == 1 and 
+            django.VERSION[1] == 11 and 
+            django.VERSION[2] == 20):
+            raise CommandError("Only support django 1.11.20")
 
         settingPath = os.path.join(path, name, 'settings.py')
         urlPath = os.path.join(path, name, 'urls.py')
 
         def renderFile(template, path, fileName, linux=False):
             temp = get_template(template)
-            content = temp.render()
+            
+            if six.PY3:
+                context = {
+                    "useConda": True,
+                }
+            else:
+                context = {
+                    "useConda": False,
+                }
+                
+            content = temp.render(context)
 
             if linux:
                 with open(os.path.join(path, fileName), 'wb') as f:
-                    f.write(six.b(content.replace('\r\n', '\n')))
+                    if not six.PY3:
+                        f.write(six.b(content.replace('\r\n', '\n')))
+                    else:
+                        f.write(content.replace('\r\n', '\n').encode())
             else:
                 with open(os.path.join(path, fileName), 'w') as f:
                     f.write(content)
 
         # file -----------------------------------------------------------------
-        renderFile('scaffold/Activate.bat', path, 'Activate.bat')
+        if not six.PY3:
+            renderFile('scaffold/Activate.bat', path, 'Activate.bat')
         renderFile('scaffold/Configure.bat', path, 'Configure.bat')
         renderFile('scaffold/Configure.sh', path, 'Configure.sh', linux=True)
         renderFile('scaffold/README.txt', path, 'README.txt')
         renderFile('scaffold/REQUIREMENTS.txt', path, 'REQUIREMENTS.txt')
+        
+        managementPath = os.path.join(
+            os.path.dirname(settingPath), "management")
+        if not os.path.exists(managementPath):
+            os.mkdir(managementPath)
+            
+        with open(os.path.join(managementPath, "__init__.py"), 'w') as f:
+            pass
+            
+        commandPath = os.path.join(managementPath, "commands")
+        if not os.path.exists(commandPath):
+            os.mkdir(commandPath)
+            
+        with open(os.path.join(commandPath, "__init__.py"), 'w') as f:
+            pass
+            
+        renderFile('scaffold/Deploy.py', commandPath, 'deploy.py')
 
         # Settings.py ----------------------------------------------------------
         with open(settingPath, 'r') as setting:
             content = setting.read()
 
         # Header
-        context = Context({
+        context = {
             "year": datetime.date.today().year,
-        })
+        }
         temp = get_template('scaffold/HeaderTemplate.py')
         header = temp.render(context)
         content = header + content
 
         # debug & mode
-        context = Context({
+        context = {
             "name": name.lower(),
-        })
+        }
         temp = get_template('scaffold/DebugTemplate.py')
         debug = temp.render(context)
         content = content.replace('DEBUG = True', debug)
@@ -109,8 +143,12 @@ class Command(BaseCommand):
         content = content.replace('ALLOWED_HOSTS = []', host)
 
         # install app
+        context = {
+            "name": name,
+        }
         temp1 = get_template('scaffold/InstalledApps.py').render()
-        temp2 = get_template('scaffold/InstalledAppsTemplate.py').render()
+        temp2 = get_template(
+            'scaffold/InstalledAppsTemplate.py').render(context)
         content = content.replace(temp1, temp2)
 
         # db & static
@@ -132,8 +170,10 @@ class Command(BaseCommand):
         content = content.strip() + '\n' + footer
 
         with open(settingPath, 'wb') as setting:
-            setting.write(six.b(utf8(content.replace('\r\n', '\n'))))
-
+            if not six.PY3:
+                setting.write(six.b(utf8(content.replace('\r\n', '\n'))))
+            else:
+                setting.write(content.replace('\r\n', '\n').encode())
         # Urls.py --------------------------------------------------------------
         with open(urlPath, 'r') as url:
             content = url.read()
