@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11380 2019-03-08 13:06:02Z Lavender $
+# $Id: __init__.py 11432 2019-04-10 06:04:43Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-03-08 22:06:02 +0900 (週五, 08 三月 2019) $
-# $Revision: 11380 $
+# $Date: 2019-04-10 15:04:43 +0900 (週三, 10 四月 2019) $
+# $Revision: 11432 $
 
 import os
 import sys
@@ -41,6 +41,8 @@ from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ugettext as _2
 from django.core.urlresolvers import reverse
 
+from Iuno.Patch import patterns
+
 CKEDITOR_CONFIGS = {
     'default': {
         'skin': 'moono',
@@ -451,7 +453,7 @@ def attachShopURLs(settings, urlpatterns):
     """
     from Iuno.shop import views
 
-    from django.conf.urls import url, patterns, include
+    from django.conf.urls import url, include
     from django.contrib.admin.views.decorators import staff_member_required
     from oscar.app import application as shop
     from paypal.express.dashboard.app import application
