@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11328 2019-01-09 14:12:55Z Lavender $
+# $Id: admin.py 11422 2019-04-03 14:03:52Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-01-09 23:12:55 +0900 (週三, 09 一月 2019) $
-# $Revision: 11328 $
+# $Date: 2019-04-03 23:03:52 +0900 (週三, 03 四月 2019) $
+# $Revision: 11422 $
 
 import os
 import datetime
 import hashlib
+import shutil
 
 from functools import update_wrapper
 from django.contrib import admin
@@ -95,29 +96,40 @@ def createVersion(model, node, conflict=False):
             backupName = "%s_%d" % (fileName, maxVersion + 1)
 
         if not preVersion.checksum == checksum:
-            if not maxVersion == 0 or not conflict:
-                version = Version.objects.create(
-                    dirName=dirName,
-                    checksum=checksum,
-                    number=maxVersion + 1,
-                    fileName=backupName,
-                    conflict=conflict,
-                    preVersion=preVersion,
-                )
-                preVersion.nextVersion = version
-                preVersion.save()
-            else:
-                preVersion.checksum = checksum
-                preVersion.save()
-                if subFileName:
-                    backupName = "%s_%d.%s" % (
-                        fileName, maxVersion, subFileName)
+            preVersionUpdateTime = datetime.datetime.fromtimestamp(
+                os.stat(preVersion.absoluteBackupPath).st_mtime)
+            currentFileUpdateTime = datetime.datetime.fromtimestamp(
+                os.stat(fullPath).st_mtime)
+            
+            if preVersionUpdateTime < currentFileUpdateTime: 
+                # 當前檔案比版控最新版本的新時，建立新版本並判斷是否衝突
+                if not maxVersion == 0 or not conflict:
+                    version = Version.objects.create(
+                        dirName=dirName,
+                        checksum=checksum,
+                        number=maxVersion + 1,
+                        fileName=backupName,
+                        conflict=conflict,
+                        preVersion=preVersion,
+                    )
+                    preVersion.nextVersion = version
+                    preVersion.save()
                 else:
-                    backupName = "%s_%d" % (fileName, maxVersion)
+                    preVersion.checksum = checksum
+                    preVersion.save()
+                    if subFileName:
+                        backupName = "%s_%d.%s" % (
+                            fileName, maxVersion, subFileName)
+                    else:
+                        backupName = "%s_%d" % (fileName, maxVersion)
 
+                    version = preVersion
+
+                createFile = True
+            else:
+                # 當前檔案比版控最新版本的舊時，不建新 Version，並且換回最新版控
                 version = preVersion
-
-            createFile = True
+                shutil.copyfile(preVersion.absoluteBackupPath, fullPath)
         else:
             version = preVersion
     else:
